summaryrefslogtreecommitdiffstats
path: root/src/config.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/config.h')
-rw-r--r--src/config.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/config.h b/src/config.h
index 7ed4b52..fed6c45 100644
--- a/src/config.h
+++ b/src/config.h
@@ -53,7 +53,7 @@ struct Config
static QCString paperType; // the page type to generate docs for
static QCString manExtension; // extension the man page files
static QCString htmlStyleSheet; // user defined cascading style sheet
- static QCString ignorePrefix; // prefix to ignore for the alphabetical index
+ static QStrList ignorePrefixList; // list of prefixes to ignore for the alphabetical index
static QStrList includePath; // list of include paths
static QStrList examplePath; // list of example paths
static QStrList imagePath; // list of image paths
@@ -112,6 +112,8 @@ struct Config
static bool generateRTF; // generate RTF flag
static bool compactRTFFlag; // generate more compact RTF
static bool rtfHyperFlag; // generate hyper links in RTF
+ static bool showIncFileFlag; // show include file in file documentation?
+ static bool stripCommentsFlag; // strip special comments from code fragments?
};
#endif